@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.012';
+$Statocles::Site::VERSION = '0.013';
 use Statocles::Class;
 
 
@@ -10,6 +10,12 @@ has title => (
 );
 
 
+has base_url => (
+    is => 'ro',
+    isa => Str,
+);
+
+
 has apps => (
     is => 'ro',
     isa => HashRef[InstanceOf['Statocles::App']],
@@ -81,16 +87,22 @@ sub write {
             if ( $index_path && $page->path eq $index_path ) {
                 # Rename the app's page so that we don't get two pages with identical
                 # content
-                $page = Statocles::Page::List->new(
-                    %{ $page },
-                    path => '/index.html',
-                );
+                $page->path( '/index.html' );
             }
             $store->write_page( $page->path, $page->render( %args ) );
         }
     }
 }
 
+
+sub url {
+    my ( $self, $path ) = @_;
+    my $base = $self->base_url;
+    $base =~ s{/$}{};
+    $path =~ s{^/}{};
+    return join "/", $base, $path;
+}
+
 1;
 
 __END__
@@ -103,7 +115,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -130,6 +142,10 @@ A Statocles::Site is a collection of L<applications|Statocles::App>.
 
 The site title, used in templates.
 
+=head2 base_url
+
+The base URL of the site, including protocol and domain. Used mostly for feeds.
+
 =head2 apps
 
 The applications in this site. Each application has a name
@@ -189,6 +205,10 @@ Write each application to its destination.
 
 Write the application to the given L<store|Statocles::Store>.
 
+=head2 url( path )
+
+Get the full URL to the given path by prepending the C<base_url>.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
